==> reverie_dreams-0.4.6%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/DeathScytheItem.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.minecraft.api.ItemLeftClickCallback;
import cc.thonly.reverie_dreams.registry.tag.RDBlockTags;
import cc.thonly.reverie_dreams.item.base.SwordItem;
import java.util.List;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3489;
import net.minecraft.class_9886;

public class DeathScytheItem extends SwordItem {
    public static final class_9886 TOOL_MATERIAL = new class_9886(RDBlockTags.EMPTY, 1561, 8.5f, 5.5f, 10, class_3489.field_52387);
    private static final double SWEEP_RADIUS = 2.5;

    public DeathScytheItem(float attackDamage, float attackSpeed, class_1793 settings) {
        super(TOOL_MATERIAL, attackDamage, attackSpeed, settings);
    }

    @Override
    public void method_7873(class_1799 stack, class_1309 target, class_1309 attacker) {
        class_1937 world = target.method_37908();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            if (serverWorld.field_9229.method_43057() < 0.28f) {
                attacker.method_6033(attacker.method_6032() + 3);
            }
        }
        super.method_7873(stack, target, attacker);
    }

    static {
        ItemLeftClickCallback.EVENT.register((level, player, hand) -> {
            if (level instanceof class_3218 world) {
                class_1799 itemStack = player.method_5998(hand);
                if (itemStack.method_7909() instanceof DeathScytheItem) {
                    class_243 center = player.method_19538().method_1031(0, player.method_17682() * 0.5, 0);
                    List<class_1297> targets = world.method_8333(
                            player,
                            player.method_5829().method_1014(SWEEP_RADIUS),
                            (e) -> e instanceof class_1309 && e != player
                    );
                    for (class_1297 target : targets) {
                        if (!(target instanceof class_1309 living)) {
                            continue;
                        }
                        if (target == player) {
                            continue;
                        }
                        class_243 toTarget = living.method_19538().method_1020(center).method_1029();
                        class_243 look = player.method_5720().method_1029();
                        if (toTarget.method_1026(look) < 0.2) {
                            continue;
                        }
                        player.method_7324(living);
                        living.method_6005(0.5, player.method_23317() - living.method_23317(), player.method_23321() - living.method_23321());
                    }
                }
            }
        });
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/weapon/DeathScytheItem.java <==
package cc.thonly.reverie_dreams.item.weapon;

import cc.thonly.minecraft.api.ItemLeftClickCallback;
import cc.thonly.reverie_dreams.registry.tag.RDBlockTags;
import cc.thonly.reverie_dreams.item.base.SwordItem;
import java.util.List;
import java.util.concurrent.ThreadLocalRandom;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3218;
import net.minecraft.class_3489;
import net.minecraft.class_9886;

public class DeathScytheItem extends SwordItem {
    public static final class_9886 TOOL_MATERIAL = new class_9886(RDBlockTags.EMPTY, 1561, 8.5f, 5.5f, 10, class_3489.field_52387);
    private static final double SWEEP_RADIUS = 2.5;

    public DeathScytheItem(float attackDamage, float attackSpeed, class_1793 settings) {
        super(TOOL_MATERIAL, attackDamage, attackSpeed, settings);
    }

    @Override
    public void method_7873(class_1799 stack, class_1309 target, class_1309 attacker) {
        class_1937 world = target.method_37908();
        if (!world.method_8608() && world instanceof class_3218 serverWorld) {
            if (ThreadLocalRandom.current().nextFloat() < 0.28f) {
                attacker.method_6033(attacker.method_6032() + 3);
            }
        }
        super.method_7873(stack, target, attacker);
    }

    static {
        ItemLeftClickCallback.EVENT.register((level, player, hand) -> {
            if (level instanceof class_3218 world) {
                class_1799 itemStack = player.method_5998(hand);
                if (itemStack.method_7909() instanceof DeathScytheItem) {
                    class_243 center = player.method_19538().method_1031(0, player.method_17682() * 0.5, 0);
                    List<class_1297> targets = world.method_8333(
                            player,
                            player.method_5829().method_1014(SWEEP_RADIUS),
                            (e) -> e instanceof class_1309 && e != player
                    );
                    for (class_1297 target : targets) {
                        if (!(target instanceof class_1309 living)) {
                            continue;
                        }
                        if (target == player) {
                            continue;
                        }
                        class_243 toTarget = living.method_19538().method_1020(center).method_1029();
                        class_243 look = player.method_5720().method_1029();
                        if (toTarget.method_1026(look) < 0.2) {
                            continue;
                        }
                        player.method_7324(living);
                        living.method_6005(0.5, player.method_23317() - living.method_23317(), player.method_23321() - living.method_23321());
                    }
                }
            }
        });
    }
}
